<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\Designation;
use App\Models\Team;
use Illuminate\Http\Request;
use Illuminate\Support\Str;
use Illuminate\Validation\Rule;
use Carbon\Carbon;
use Image;

class DesignationController extends Controller
{
    public function __construct()
    {
        $this->middleware('auth');
    }

    public function index()
    {
        return view('admin.designation', [
            'designations' => Designation::get(),
        ]);
    }

    public function designation_add()
    {
        return view('admin.designation_add');
    }

    public function insert(Request $request)
    {
        if(env('PROJECT_MODE') == 0) {
            return redirect()->back()->with('error', env('PROJECT_NOTIFICATION'));
        }

        $request->validate([
            'designation_name' => 'required|unique:designations'
        ]);
        Designation::create([
            'designation_name' => $request->designation_name
        ]);
        return Redirect()->route('admin.designation')->with('success', A_SUCCESS_DATA_ADD);
    }

    public function edit_page($id)
    {
        return view('admin.designation_edit', [
            'des' => Designation::find($id),
        ]);
    }

    public function edit(Request $request)
    {
        if(env('PROJECT_MODE') == 0) {
            return redirect()->back()->with('error', env('PROJECT_NOTIFICATION'));
        }

        $id = $request->id;
        $request->validate([
            'designation_name' => ['required',Rule::unique('designations')->ignore($id),],
        ]);
        $designation = Designation::findOrFail($id);
        $designation->designation_name = $request->designation_name;
        $designation->update();
        return Redirect()->route('admin.designation')->with('success', A_SUCCESS_DATA_UPDATE);
    }

    public function delete($id)
    {
        if(env('PROJECT_MODE') == 0) {
            return redirect()->back()->with('error', env('PROJECT_NOTIFICATION'));
        }
        
        $total = Team::where('designation_id', $id)->count();
        if($total > 0) {
            return Redirect()->back()->with('error', 'A_ERROR_DATA_NOT_DELETE_FOR_ANOTHER_TABLE');
        }

        Designation::find($id)->forceDelete();
        return Redirect()->route('admin.designation')->with('success', A_SUCCESS_DATA_DELETE);
    }
}
