<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\Page;
use Illuminate\Http\Request;
use Image;

class PageController extends Controller
{
    public function __construct()
    {
        $this->middleware('auth');
    }

    public function index()
    {
        return view('admin.page', [
            'page' => Page::find(1),
        ]);
    }

    public function home_page_update(Request $req)
    {
        if(env('PROJECT_MODE') == 0) {
            return redirect()->back()->with('error', env('PROJECT_NOTIFICATION'));
        }

        $req->validate([
            'mt_home' => 'required',
        ],[],[
            'mt_home' => 'Home Meta Title'
        ]);

        Page::find(1)->update([
            "mt_home" => $req->mt_home,
            "md_home" => $req->md_home,
        ]);
        return back()->with('success', A_SUCCESS_DATA_UPDATE);
    }


    public function about_page_update(Request $request)
    {
        if(env('PROJECT_MODE') == 0) {
            return redirect()->back()->with('error', env('PROJECT_NOTIFICATION'));
        }

        $request->validate([
            'about_heading' => 'required',
            'about_content' => 'required'
        ]);

        $about_data = Page::find(1);

        if ($request->hasFile('about_photo')) {
            $request->validate([
                'about_photo' => 'required|file|image'
            ]);
            $file = $request->file('about_photo');
            $ext = $file->getClientOriginalExtension();
            @unlink(public_path('uploads/'.$about_data->about_photo));
            $filename1 = 'about_photo'.'.'.$ext;
            $file->move(public_path('uploads'),$filename1);
            $about_data->about_photo = $filename1;
        }

        $about_data->about_heading = $request->about_heading;
        $about_data->about_content = $request->about_content;
        $about_data->vision_heading = $request->vision_heading;
        $about_data->vision_content = $request->vision_content;
        $about_data->mission_heading = $request->mission_heading;
        $about_data->mission_content = $request->mission_content;
        $about_data->mt_about = $request->mt_about;
        $about_data->md_about = $request->md_about;
        $about_data->update();

        return back()->with('success', A_SUCCESS_DATA_UPDATE);
    }


    public function gallery_page_update(Request $req)
    {
        if(env('PROJECT_MODE') == 0) {
            return redirect()->back()->with('error', env('PROJECT_NOTIFICATION'));
        }

        $req->validate([
            'gallery_heading' => 'required'
        ]);

        Page::find(1)->update([
            "gallery_heading" => $req->gallery_heading,
            "mt_gallery" => $req->mt_gallery,
            "md_gallery" => $req->md_gallery,
        ]);
        return back()->with('success', A_SUCCESS_DATA_UPDATE);
    }

    public function faq_page_update(Request $req)
    {
        if(env('PROJECT_MODE') == 0) {
            return redirect()->back()->with('error', env('PROJECT_NOTIFICATION'));
        }

        $req->validate([
            'faq_heading' => 'required'
        ]);

        Page::find(1)->update([
            "faq_heading" => $req->faq_heading,
            "mt_faq" => $req->mt_faq,
            "md_faq" => $req->md_faq,
        ]);
        return back()->with('success', A_SUCCESS_DATA_UPDATE);
    }

    public function service_page_update(Request $req)
    {
        if(env('PROJECT_MODE') == 0) {
            return redirect()->back()->with('error', env('PROJECT_NOTIFICATION'));
        }

        $req->validate([
            'service_heading' => 'required'
        ]);

        Page::find(1)->update([
            "service_heading" => $req->service_heading,
            "mt_service" => $req->mt_service,
            "md_service" => $req->md_service,
        ]);
        return back()->with('success', A_SUCCESS_DATA_UPDATE);
    }

    public function portfolio_page_update(Request $req)
    {
        if(env('PROJECT_MODE') == 0) {
            return redirect()->back()->with('error', env('PROJECT_NOTIFICATION'));
        }

        $req->validate([
            'portfolio_heading' => 'required'
        ]);

        Page::find(1)->update([
            "portfolio_heading" => $req->portfolio_heading,
            "mt_portfolio" => $req->mt_portfolio,
            "md_portfolio" => $req->md_portfolio,
        ]);
        return back()->with('success', A_SUCCESS_DATA_UPDATE);
    }

    public function testimonial_page_update(Request $req)
    {
        if(env('PROJECT_MODE') == 0) {
            return redirect()->back()->with('error', env('PROJECT_NOTIFICATION'));
        }

        $req->validate([
            'testimonial_heading' => 'required'
        ]);

        Page::find(1)->update([
            "testimonial_heading" => $req->testimonial_heading,
            "mt_testimonial" => $req->mt_testimonial,
            "md_testimonial" => $req->md_testimonial,
        ]);
        return back()->with('success', A_SUCCESS_DATA_UPDATE);
    }

    public function news_page_update(Request $req)
    {
        if(env('PROJECT_MODE') == 0) {
            return redirect()->back()->with('error', env('PROJECT_NOTIFICATION'));
        }

        $req->validate([
            'news_heading' => 'required'
        ]);

        Page::find(1)->update([
            "news_heading" => $req->news_heading,
            "mt_news" => $req->mt_news,
            "md_news" => $req->md_news,
        ]);
        return back()->with('success', A_SUCCESS_DATA_UPDATE);
    }

    public function contact_page_update(Request $req)
    {
        if(env('PROJECT_MODE') == 0) {
            return redirect()->back()->with('error', env('PROJECT_NOTIFICATION'));
        }

        $req->validate([
            'contact_heading' => 'required'
        ]);

        Page::find(1)->update([
            "contact_heading" => $req->contact_heading,
            "mt_contact" => $req->mt_contact,
            "md_contact" => $req->md_contact,
        ]);
        return back()->with('success', A_SUCCESS_DATA_UPDATE);
    }

    public function search_page_update(Request $req)
    {
        if(env('PROJECT_MODE') == 0) {
            return redirect()->back()->with('error', env('PROJECT_NOTIFICATION'));
        }

        $req->validate([
            'search_heading' => 'required'
        ]);

        Page::find(1)->update([
            "search_heading" => $req->search_heading,
            "mt_search" => $req->mt_search,
            "md_search" => $req->md_search,
        ]);
        return back()->with('success', A_SUCCESS_DATA_UPDATE);
    }

    public function term_page_update(Request $req)
    {
        if(env('PROJECT_MODE') == 0) {
            return redirect()->back()->with('error', env('PROJECT_NOTIFICATION'));
        }

        $req->validate([
            'term_heading' => 'required',
            'term_content' => 'required'
        ]);

        Page::find(1)->update([
            "term_heading" => $req->term_heading,
            "term_content" => $req->term_content,
            "mt_term" => $req->mt_term,
            "md_term" => $req->md_term,
        ]);
        return back()->with('success', A_SUCCESS_DATA_UPDATE);
    }

    public function privacy_page_update(Request $req)
    {
        if(env('PROJECT_MODE') == 0) {
            return redirect()->back()->with('error', env('PROJECT_NOTIFICATION'));
        }
        
        $req->validate([
            'privacy_heading' => 'required',
            'privacy_content' => 'required'
        ]);

        Page::find(1)->update([
            "privacy_heading" => $req->privacy_heading,
            "privacy_content" => $req->privacy_content,
            "mt_privacy" => $req->mt_privacy,
            "md_privacy" => $req->md_privacy,
        ]);
        return back()->with('success', A_SUCCESS_DATA_UPDATE);
    }
}
