<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\Partner;
use Illuminate\Http\Request;
use Illuminate\Support\Str;
use Illuminate\Validation\Rule;
use Carbon\Carbon;
use Image;

class PartnerController extends Controller
{
    public function __construct()
    {
        $this->middleware('auth');
    }

    public function index()
    {
        return view('admin.partner', [
            'partners' => Partner::get(),
        ]);
    }

    public function partner_add()
    {
        return view('admin.partner_add');
    }

    public function insert(Request $request)
    {
        if(env('PROJECT_MODE') == 0) {
            return redirect()->back()->with('error', env('PROJECT_NOTIFICATION'));
        }

        $request->validate([
            'name' => 'required',
            'photo' => 'required|file|image'
        ]);

        if ($request->hasFile('photo')) {
            $file = $request->file('photo');
            $ext = $file->getClientOriginalExtension();
            $filename1 = 'partner_'.md5(mt_rand(11111111,99999999)).'.'.$ext;
            $file->move(public_path('uploads'),$filename1);
        }

        Partner::create([
            'name' => $request->name,
            'photo' => $filename1
        ]);

        return Redirect()->route('admin.partner')->with('success', A_SUCCESS_DATA_ADD);
    }

    public function edit_page($id)
    {
        return view('admin.partner_edit', [
            'partner' => Partner::find($id),
        ]);
    }

    public function edit(Request $request)
    {
        if(env('PROJECT_MODE') == 0) {
            return redirect()->back()->with('error', env('PROJECT_NOTIFICATION'));
        }

        $id = $request->id;

        $request->validate([
            'name' => 'required'
        ]);

        $partner = Partner::findOrFail($id);

        if ($request->hasFile('photo')) {
            $request->validate([
                'photo' => 'image'
            ]);
            $file = $request->file('photo');
            $ext = $file->getClientOriginalExtension();
            @unlink(public_path('uploads/'.$partner->photo));
            $filename1 = 'partner_'.md5(mt_rand(11111111,99999999)).'.'.$ext;
            $file->move(public_path('uploads'),$filename1);
            $partner->photo = $filename1;
        }

        $partner->name = $request->name;
        $partner->update();

        return Redirect()->route('admin.partner')->with('success', A_SUCCESS_DATA_UPDATE);
    }

    public function delete($id)
    {
        if(env('PROJECT_MODE') == 0) {
            return redirect()->back()->with('error', env('PROJECT_NOTIFICATION'));
        }
        
        $photo = Partner::find($id)->photo;
        unlink(public_path('uploads/' . $photo));
        Partner::find($id)->forceDelete();
        return Redirect()->route('admin.partner')->with('success', A_SUCCESS_DATA_DELETE);
    }
}
