<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\Testimonial;
use Illuminate\Http\Request;
use Illuminate\Support\Str;
use Illuminate\Validation\Rule;
use Carbon\Carbon;
use Image;

class TestimonialController extends Controller
{
    public function __construct()
    {
        $this->middleware('auth');
    }

    public function index()
    {
        return view('admin.testimonial', [
            'testimonials' => Testimonial::get(),
        ]);
    }

    public function testimonial_add()
    {
        return view('admin.testimonial_add');
    }

    public function insert(Request $request)
    {
        if(env('PROJECT_MODE') == 0) {
            return redirect()->back()->with('error', env('PROJECT_NOTIFICATION'));
        }

        $request->validate([
            'name' => 'required',
            'designation' => 'required',
            'photo' => 'required|file|image',
            'comment' => 'required',
        ]);

        if ($request->hasFile('photo')) {
            $file = $request->file('photo');
            $ext = $file->getClientOriginalExtension();
            $filename1 = 'testimonial_'.md5(mt_rand(11111111,99999999)).'.'.$ext;
            $file->move(public_path('uploads'),$filename1);
        }

        Testimonial::create([
            'name' => $request->name,
            'designation' => $request->designation,
            'photo' => $filename1,
            'comment' => $request->comment
        ]);

        return Redirect()->route('admin.testimonial')->with('success', A_SUCCESS_DATA_ADD);
    }

    public function edit_page($id)
    {
        return view('admin.testimonial_edit', [
            'testimonial' => Testimonial::find($id),
        ]);
    }

    public function edit(Request $request)
    {
        if(env('PROJECT_MODE') == 0) {
            return redirect()->back()->with('error', env('PROJECT_NOTIFICATION'));
        }

        $id = $request->id;

        $request->validate([
            'name' => 'required',
            'designation' => 'required',
            'comment' => 'required',
        ]);

        $testimonial = Testimonial::findOrFail($id);

        if ($request->hasFile('photo')) {
            $request->validate([
                'photo' => 'image'
            ]);
            $file = $request->file('photo');
            $ext = $file->getClientOriginalExtension();
            @unlink(public_path('uploads/'.$testimonial->photo));
            $filename1 = 'testimonial_'.md5(mt_rand(11111111,99999999)).'.'.$ext;
            $file->move(public_path('uploads'),$filename1);
            $testimonial->photo = $filename1;
        }

        $testimonial->name        = $request->name;
        $testimonial->designation = $request->designation;
        $testimonial->comment     = $request->comment;
        $testimonial->update();

        return Redirect()->route('admin.testimonial')->with('success', A_SUCCESS_DATA_UPDATE);
    }

    public function delete($id)
    {
        if(env('PROJECT_MODE') == 0) {
            return redirect()->back()->with('error', env('PROJECT_NOTIFICATION'));
        }
        
        $photo = Testimonial::find($id)->photo;
        unlink(public_path('uploads/' . $photo));
        Testimonial::find($id)->forceDelete();
        return Redirect()->route('admin.testimonial')->with('success', A_SUCCESS_DATA_DELETE);
    }
}
